@@ -15,6 +15,14 @@ log = logging.getLogger("uvc.main")
 
 dialects = dict(hg=hg.HgDialect(), svn=svn.SVNDialect())
 
+class IOWrapper(object):
+    def __init__(self, file):
+        self.file = file
+        self.return_code = None
+        
+    def __getattr__(self, attr):
+        return getattr(self.file, attr)
+
 class Context(object):
     # all schemes are allowed
     remote_scheme_whitelist = None
@@ -23,7 +31,8 @@ class Context(object):
     # want a user to flag the commits, etc.
     user = None
     
-    def __init__(self, working_dir, auth=None, timeout=-1):
+    def __init__(self, working_dir, auth=None, timeout=-1,
+                 output=None):
         """working_dir is the working directory in which commands should
         run. auth is a dictionary of authentication information:
         
@@ -34,10 +43,16 @@ class Context(object):
         
         timeout is the time (in seconds) that the command is allowed
         to run.
+        
+        output is a file-like object (specifically with a write method)
+        to which the output is sent and return_code is set when
+        the command is done. If it's not specified, it's set
+        to sys.stdout.
         """
         self.working_dir = path(working_dir)
         self.auth = auth
         self.timeout = timeout
+        self.output = IOWrapper(sys.stdout) if output is None else output
         
     def _normalize_path(self, unnorm_path):
         norm_path = self.working_dir / path(unnorm_path)
@@ -174,21 +189,19 @@ def run_command(command, context):
     # generic "commit", which is supposed to commit locally,
     # the command itself runs no vcs commands.
     if not command_line:
-        return command.get_output()
+        return command.generate_output(context)
         
     log.debug("Running: %s", (command_line,))
     log.debug("Working dir: %s", context.working_dir)
     
-    returncode, stdout = run_in_directory(context.working_dir, command_line, 
-        timeout=context.timeout)
+    run_in_directory(context.working_dir, command_line, 
+        timeout=context.timeout, 
+        output=context.output)
     
-    if returncode == 0 and hasattr(command, "command_successful"):
+    if context.output.return_code == 0 and \
+        hasattr(command, "command_successful"):
         command.command_successful()
     
-    output = command.process_output(returncode, stdout)
-    log.debug("Command output: %s", output)
-    return output
-
 def _get_command_with_blanks_filled_in(context, args, dialect):
     """This will launch the user's text editor for
     items that really need to be filled in (such as
@@ -237,6 +250,5 @@ def run(args=None):
         dialect = None
     
     command = _get_command_with_blanks_filled_in(context, args, dialect)
-    output = run_command(command, context)
-    print str(output)
+    run_command(command, context)
     
\ No newline at end of file
