@@ -83,6 +83,17 @@ def test_remove_command():
     except UVCError:
         pass
 
+def test_revert_command():
+    revert = commands.revert(test_context, ["myfile"])
+    assert not revert.reads_remote
+    assert not revert.writes_remote
+    assert revert.targets == ["myfile"]
+    assert str(revert) == "revert myfile"
+    
+    revert = commands.revert(test_context, [])
+    assert revert.targets == None
+    assert str(revert) == "revert"
+
 
 def test_push_command():
     push = commands.push(test_context, [])
@@ -258,6 +269,13 @@ def test_diff_is_secured():
         assert False, "Expected exception for going above topdir"
     except commands.SecurityError:
         pass
+
+def test_revert_is_secured():
+    try:
+        revert = commands.revert(secure_context, [topdir / ".." / "foo"])
+        assert False, "Expected exception for going above topdir"
+    except commands.SecurityError:
+        pass
         
 def test_status_is_secured():
     try:
